==> versatile-kernel-2.6.18.1-compiled.tar.bz2: linux-2.6.18.1/drivers/base/firmware_class.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0xe3e52f33, "struct_module" },
	{ 0x4d247e92, "module_refcount" },
	{ 0x9afe9c91, "__mod_timer" },
	{ 0x9e24e586, "class_register" },
	{ 0xd6ee688f, "vmalloc" },
	{ 0x75b38522, "del_timer" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x102857f4, "kobject_uevent" },
	{ 0xaf8df48e, "class_device_unregister" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x2fd1d81c, "vfree" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x7d11c268, "jiffies" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0x5f754e5a, "memset" },
	{ 0xdd132261, "printk" },
	{ 0x43a89bb3, "class_unregister" },
	{ 0x73e20c1c, "strlcpy" },
	{ 0xde9cc24, "class_device_create_file" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0x50c2f10f, "class_create_file" },
	{ 0x7dceceac, "capable" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x72df44a2, "class_device_register" },
	{ 0xf4e59dd4, "wake_up_process" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x35fe47a1, "init_timer" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0x9d669763, "memcpy" },
	{ 0x95fac3ab, "sysfs_create_bin_file" },
	{ 0x7e9ebb05, "kernel_thread" },
	{ 0xb742fd7, "simple_strtol" },
	{ 0xa218bf61, "complete" },
	{ 0xdc43a9c8, "daemonize" },
	{ 0x45e87ae6, "add_uevent_var" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";

==> versatile-kernel-2.6.19.1-compiled.tar.bz2: linux-2.6.19.1/drivers/base/firmware_class.mod.c <==
#include <linux/module.h>
#include <linux/vermagic.h>
#include <linux/compiler.h>

MODULE_INFO(vermagic, VERMAGIC_STRING);

struct module __this_module
__attribute__((section(".gnu.linkonce.this_module"))) = {
 .name = KBUILD_MODNAME,
 .init = init_module,
#ifdef CONFIG_MODULE_UNLOAD
 .exit = cleanup_module,
#endif
};

static const struct modversion_info ____versions[]
__attribute_used__
__attribute__((section("__versions"))) = {
	{ 0x528a560b, "struct_module" },
	{ 0xf13921fd, "module_refcount" },
	{ 0x9afe9c91, "__mod_timer" },
	{ 0xb44da5b0, "class_register" },
	{ 0xd6ee688f, "vmalloc" },
	{ 0x75b38522, "del_timer" },
	{ 0xb13d73c9, "malloc_sizes" },
	{ 0x91459ece, "kobject_uevent" },
	{ 0xc5ea0cc6, "class_device_unregister" },
	{ 0x323222ba, "mutex_unlock" },
	{ 0x2fd1d81c, "vfree" },
	{ 0x1d26aa98, "sprintf" },
	{ 0x7d11c268, "jiffies" },
	{ 0x25fa6f17, "wait_for_completion" },
	{ 0x5f754e5a, "memset" },
	{ 0xdd132261, "printk" },
	{ 0x739cb0ec, "class_unregister" },
	{ 0x73e20c1c, "strlcpy" },
	{ 0x2954bf, "class_device_create_file" },
	{ 0xb97d4c9c, "mutex_lock" },
	{ 0xff066780, "class_create_file" },
	{ 0x7dceceac, "capable" },
	{ 0x8523fd53, "kmem_cache_alloc" },
	{ 0x6b2dc060, "dump_stack" },
	{ 0x7ef86b82, "class_device_register" },
	{ 0x464b4846, "wake_up_process" },
	{ 0x6cb34e5, "init_waitqueue_head" },
	{ 0x35fe47a1, "init_timer" },
	{ 0xc818ff24, "kmem_cache_zalloc" },
	{ 0x37a0cba, "kfree" },
	{ 0xcfea89a, "kthread_create" },
	{ 0x9d669763, "memcpy" },
	{ 0x9f0f2ece, "sysfs_create_bin_file" },
	{ 0xb742fd7, "simple_strtol" },
	{ 0xa218bf61, "complete" },
	{ 0x45e87ae6, "add_uevent_var" },
};

static const char __module_depends[]
__attribute_used__
__attribute__((section(".modinfo"))) =
"depends=";
